@@ -223,10 +223,9 @@ def test_command_line_arguments():
     # If no options check for -u.  If -u exists, help_message.  If -u does not exist, continue to new user prompts.
     # If -u is not set, help_message
     if results.qetl_user_home_dir is None:
-        help_message(f" "
-                     f"Please enter -u [ your opt/qetl/users/ user home directory path ]\n"
-                     f"    Note: opt/qetl/users/newuser is the root directory for your qetl userhome directory,\n" 
-                     f"          enter a new path including the opt/qetl/users/newuser \n"
+        help_message(f"Please enter -u [ your opt/qetl/users/ user home directory path ]\n\n"
+                     f"    Note: /opt/qetl/users/newuser is the root directory for your qetl userhome directory,\n" 
+                     f"           enter a new path including the opt/qetl/users/newuser \n"
                      f"           in the path you have authorization to write to.\n"
                      f"           the prefix to your user directory opt/qetl/users is required.\n"
                      f"    Example:\n"
@@ -300,6 +299,11 @@ def setup_qetl_user_home_dir_environment():
         print(f"\nqetl_user_home_dir does not exist: {etld_lib_config.qetl_user_home_dir}")
         response = input(f"Create new qetl_user_home_dir? {etld_lib_config.qetl_user_home_dir} ( yes or no ): ")
         if response == 'yes':
+            if command_line_arguments.execute_etl_module is not None:
+                if command_line_arguments.logs is None:
+                    etld_lib_functions.main(log_level=logging.WARNING, my_logger_prog_name='qetl_manage_user')
+                else:
+                    etld_lib_functions.main(log_level=logging.INFO, my_logger_prog_name='qetl_manage_user')
             etld_lib_config.qetl_create_user_dirs_ok_flag = True
             etld_lib_config.main()
             time.sleep(1)
@@ -310,6 +314,7 @@ def setup_qetl_user_home_dir_environment():
                 print("")
                 if_qualys_test_login(first_time=True)
             print(f"\nThank you, exiting.\n")
+            exit(0)
         else:
             print(f"\nThank you, exiting.\n")
             exit(1)
@@ -319,9 +324,9 @@ def main():
     get_command_line_arguments(sys.argv[1:])
     test_command_line_arguments()
     setup_qetl_user_home_dir_environment()
-    if_execute_etl_module()
     if_update_credentials()
     if_qualys_test_login()
+    if_execute_etl_module()
     if_print_report()
 
 
